// Generated by gir (https://github.com/gtk-rs/gir @ 1bef39f)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files.git @ 7d95377)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "HdyActionRow", sizeof(HdyActionRow), alignof(HdyActionRow));
    printf("%s;%zu;%zu\n", "HdyActionRowClass", sizeof(HdyActionRowClass), alignof(HdyActionRowClass));
    printf("%s;%zu;%zu\n", "HdyApplicationWindow", sizeof(HdyApplicationWindow), alignof(HdyApplicationWindow));
    printf("%s;%zu;%zu\n", "HdyApplicationWindowClass", sizeof(HdyApplicationWindowClass), alignof(HdyApplicationWindowClass));
    printf("%s;%zu;%zu\n", "HdyAvatarClass", sizeof(HdyAvatarClass), alignof(HdyAvatarClass));
    printf("%s;%zu;%zu\n", "HdyCarouselClass", sizeof(HdyCarouselClass), alignof(HdyCarouselClass));
    printf("%s;%zu;%zu\n", "HdyCarouselIndicatorDotsClass", sizeof(HdyCarouselIndicatorDotsClass), alignof(HdyCarouselIndicatorDotsClass));
    printf("%s;%zu;%zu\n", "HdyCarouselIndicatorLinesClass", sizeof(HdyCarouselIndicatorLinesClass), alignof(HdyCarouselIndicatorLinesClass));
    printf("%s;%zu;%zu\n", "HdyCenteringPolicy", sizeof(HdyCenteringPolicy), alignof(HdyCenteringPolicy));
    printf("%s;%zu;%zu\n", "HdyClampClass", sizeof(HdyClampClass), alignof(HdyClampClass));
    printf("%s;%zu;%zu\n", "HdyComboRow", sizeof(HdyComboRow), alignof(HdyComboRow));
    printf("%s;%zu;%zu\n", "HdyComboRowClass", sizeof(HdyComboRowClass), alignof(HdyComboRowClass));
    printf("%s;%zu;%zu\n", "HdyDeck", sizeof(HdyDeck), alignof(HdyDeck));
    printf("%s;%zu;%zu\n", "HdyDeckClass", sizeof(HdyDeckClass), alignof(HdyDeckClass));
    printf("%s;%zu;%zu\n", "HdyDeckTransitionType", sizeof(HdyDeckTransitionType), alignof(HdyDeckTransitionType));
    printf("%s;%zu;%zu\n", "HdyEnumValueObjectClass", sizeof(HdyEnumValueObjectClass), alignof(HdyEnumValueObjectClass));
    printf("%s;%zu;%zu\n", "HdyExpanderRow", sizeof(HdyExpanderRow), alignof(HdyExpanderRow));
    printf("%s;%zu;%zu\n", "HdyExpanderRowClass", sizeof(HdyExpanderRowClass), alignof(HdyExpanderRowClass));
    printf("%s;%zu;%zu\n", "HdyFlapClass", sizeof(HdyFlapClass), alignof(HdyFlapClass));
    printf("%s;%zu;%zu\n", "HdyFlapFoldPolicy", sizeof(HdyFlapFoldPolicy), alignof(HdyFlapFoldPolicy));
    printf("%s;%zu;%zu\n", "HdyFlapTransitionType", sizeof(HdyFlapTransitionType), alignof(HdyFlapTransitionType));
    printf("%s;%zu;%zu\n", "HdyHeaderBar", sizeof(HdyHeaderBar), alignof(HdyHeaderBar));
    printf("%s;%zu;%zu\n", "HdyHeaderBarClass", sizeof(HdyHeaderBarClass), alignof(HdyHeaderBarClass));
    printf("%s;%zu;%zu\n", "HdyHeaderGroupChildClass", sizeof(HdyHeaderGroupChildClass), alignof(HdyHeaderGroupChildClass));
    printf("%s;%zu;%zu\n", "HdyHeaderGroupChildType", sizeof(HdyHeaderGroupChildType), alignof(HdyHeaderGroupChildType));
    printf("%s;%zu;%zu\n", "HdyHeaderGroupClass", sizeof(HdyHeaderGroupClass), alignof(HdyHeaderGroupClass));
    printf("%s;%zu;%zu\n", "HdyKeypad", sizeof(HdyKeypad), alignof(HdyKeypad));
    printf("%s;%zu;%zu\n", "HdyKeypadClass", sizeof(HdyKeypadClass), alignof(HdyKeypadClass));
    printf("%s;%zu;%zu\n", "HdyLeaflet", sizeof(HdyLeaflet), alignof(HdyLeaflet));
    printf("%s;%zu;%zu\n", "HdyLeafletClass", sizeof(HdyLeafletClass), alignof(HdyLeafletClass));
    printf("%s;%zu;%zu\n", "HdyLeafletTransitionType", sizeof(HdyLeafletTransitionType), alignof(HdyLeafletTransitionType));
    printf("%s;%zu;%zu\n", "HdyNavigationDirection", sizeof(HdyNavigationDirection), alignof(HdyNavigationDirection));
    printf("%s;%zu;%zu\n", "HdyPreferencesGroup", sizeof(HdyPreferencesGroup), alignof(HdyPreferencesGroup));
    printf("%s;%zu;%zu\n", "HdyPreferencesGroupClass", sizeof(HdyPreferencesGroupClass), alignof(HdyPreferencesGroupClass));
    printf("%s;%zu;%zu\n", "HdyPreferencesPage", sizeof(HdyPreferencesPage), alignof(HdyPreferencesPage));
    printf("%s;%zu;%zu\n", "HdyPreferencesPageClass", sizeof(HdyPreferencesPageClass), alignof(HdyPreferencesPageClass));
    printf("%s;%zu;%zu\n", "HdyPreferencesRow", sizeof(HdyPreferencesRow), alignof(HdyPreferencesRow));
    printf("%s;%zu;%zu\n", "HdyPreferencesRowClass", sizeof(HdyPreferencesRowClass), alignof(HdyPreferencesRowClass));
    printf("%s;%zu;%zu\n", "HdyPreferencesWindow", sizeof(HdyPreferencesWindow), alignof(HdyPreferencesWindow));
    printf("%s;%zu;%zu\n", "HdyPreferencesWindowClass", sizeof(HdyPreferencesWindowClass), alignof(HdyPreferencesWindowClass));
    printf("%s;%zu;%zu\n", "HdySearchBar", sizeof(HdySearchBar), alignof(HdySearchBar));
    printf("%s;%zu;%zu\n", "HdySearchBarClass", sizeof(HdySearchBarClass), alignof(HdySearchBarClass));
    printf("%s;%zu;%zu\n", "HdySqueezerClass", sizeof(HdySqueezerClass), alignof(HdySqueezerClass));
    printf("%s;%zu;%zu\n", "HdySqueezerTransitionType", sizeof(HdySqueezerTransitionType), alignof(HdySqueezerTransitionType));
    printf("%s;%zu;%zu\n", "HdyStatusPageClass", sizeof(HdyStatusPageClass), alignof(HdyStatusPageClass));
    printf("%s;%zu;%zu\n", "HdySwipeGroupClass", sizeof(HdySwipeGroupClass), alignof(HdySwipeGroupClass));
    printf("%s;%zu;%zu\n", "HdySwipeTrackerClass", sizeof(HdySwipeTrackerClass), alignof(HdySwipeTrackerClass));
    printf("%s;%zu;%zu\n", "HdySwipeableInterface", sizeof(HdySwipeableInterface), alignof(HdySwipeableInterface));
    printf("%s;%zu;%zu\n", "HdyTabBarClass", sizeof(HdyTabBarClass), alignof(HdyTabBarClass));
    printf("%s;%zu;%zu\n", "HdyTabPageClass", sizeof(HdyTabPageClass), alignof(HdyTabPageClass));
    printf("%s;%zu;%zu\n", "HdyTabViewClass", sizeof(HdyTabViewClass), alignof(HdyTabViewClass));
    printf("%s;%zu;%zu\n", "HdyTitleBarClass", sizeof(HdyTitleBarClass), alignof(HdyTitleBarClass));
    printf("%s;%zu;%zu\n", "HdyValueObjectClass", sizeof(HdyValueObjectClass), alignof(HdyValueObjectClass));
    printf("%s;%zu;%zu\n", "HdyViewSwitcherBarClass", sizeof(HdyViewSwitcherBarClass), alignof(HdyViewSwitcherBarClass));
    printf("%s;%zu;%zu\n", "HdyViewSwitcherClass", sizeof(HdyViewSwitcherClass), alignof(HdyViewSwitcherClass));
    printf("%s;%zu;%zu\n", "HdyViewSwitcherPolicy", sizeof(HdyViewSwitcherPolicy), alignof(HdyViewSwitcherPolicy));
    printf("%s;%zu;%zu\n", "HdyViewSwitcherTitleClass", sizeof(HdyViewSwitcherTitleClass), alignof(HdyViewSwitcherTitleClass));
    printf("%s;%zu;%zu\n", "HdyWindow", sizeof(HdyWindow), alignof(HdyWindow));
    printf("%s;%zu;%zu\n", "HdyWindowClass", sizeof(HdyWindowClass), alignof(HdyWindowClass));
    printf("%s;%zu;%zu\n", "HdyWindowHandleClass", sizeof(HdyWindowHandleClass), alignof(HdyWindowHandleClass));
    return 0;
}
